@@ -34,23 +34,23 @@ in this Software without prior written authorization from The Open Group.
 #include "VendorP.h"
 #include "CreateI.h"
 
-
-#if defined(AIXSHLIB) || defined(__UNIXOS2__)
+#if defined(AIXSHLIB)
 WidgetClass vendorShellWidgetClass = (WidgetClass) &vendorShellClassRec;
 
-static void _XtVendorInitialize()
+static void
+_XtVendorInitialize()
 {
     transientShellWidgetClass->core_class.superclass =
-	(WidgetClass) &vendorShellClassRec;
+        (WidgetClass) &vendorShellClassRec;
     topLevelShellWidgetClass->core_class.superclass =
-	(WidgetClass) &vendorShellClassRec;
+        (WidgetClass) &vendorShellClassRec;
 }
 
 #define VENDORINIT _XtVendorInitialize();
 
 #else
 
-#define VENDORINIT /* as nothing */
+#define VENDORINIT              /* as nothing */
 
 #endif
 
@@ -59,9 +59,11 @@ static void _XtVendorInitialize()
  * _XtInherit needs to be statically linked since it is compared against as
  * well as called.
  */
-void _XtInherit()
+void
+_XtInherit()
 {
     extern void __XtInherit();
+
     __XtInherit();
 }
 #endif
@@ -74,117 +76,108 @@ void _XtInherit()
  *       call XtToolkitInitialize.
  */
 
-void XtToolkitInitialize()
+void
+XtToolkitInitialize()
 {
     extern void _XtToolkitInitialize();
-    VENDORINIT
-    _XtToolkitInitialize();
+
+    VENDORINIT _XtToolkitInitialize();
 }
 
 Widget
-XtInitialize(
-    _Xconst char* name,
-    _Xconst char* classname,
-    XrmOptionDescRec *options,
-    Cardinal num_options,
-    int *argc,
-    String *argv)
+XtInitialize(_Xconst char *name,
+             _Xconst char *classname,
+             XrmOptionDescRec *options,
+             Cardinal num_options, int *argc, String *argv)
 {
     extern Widget _XtInitialize();
+
     VENDORINIT
-    return _XtInitialize (name, classname, options, num_options, argc, argv);
+        return _XtInitialize(name, classname, options, num_options, argc, argv);
 }
 
 Widget
-XtAppInitialize(
-    XtAppContext * app_context_return,
-    _Xconst char* application_class,
-    XrmOptionDescRec *options,
-    Cardinal num_options,
-    int *argc_in_out,
-    String *argv_in_out,
-    String *fallback_resources,
-    ArgList args_in,
-    Cardinal num_args_in)
+XtAppInitialize(XtAppContext *app_context_return,
+                _Xconst char *application_class,
+                XrmOptionDescRec *options,
+                Cardinal num_options,
+                int *argc_in_out,
+                String *argv_in_out,
+                String *fallback_resources,
+                ArgList args_in, Cardinal num_args_in)
 {
     extern Widget _XtAppInitialize();
+
     VENDORINIT
-    return _XtAppInitialize (app_context_return, application_class, options,
-			     num_options, argc_in_out, argv_in_out,
-			     fallback_resources, args_in, num_args_in);
+        return _XtAppInitialize(app_context_return, application_class, options,
+                                num_options, argc_in_out, argv_in_out,
+                                fallback_resources, args_in, num_args_in);
 }
 
 Widget
-XtVaAppInitialize(
-    XtAppContext *app_context_return,
-    _Xconst char* application_class,
-    XrmOptionDescList options,
-    Cardinal num_options,
-    int *argc_in_out,
-    String *argv_in_out,
-    String *fallback_resources,
-    ...)
+XtVaAppInitialize(XtAppContext *app_context_return,
+                  _Xconst char *application_class,
+                  XrmOptionDescList options,
+                  Cardinal num_options,
+                  int *argc_in_out,
+                  String *argv_in_out, String *fallback_resources, ...)
 {
-    va_list	var;
+    va_list var;
     extern Widget _XtVaAppInitialize();
 
-    VENDORINIT
-    va_start(var, fallback_resources);
+    VENDORINIT va_start(var, fallback_resources);
+
     return _XtVaAppInitialize(app_context_return, application_class, options,
-			      num_options, argc_in_out, argv_in_out,
-			      fallback_resources, var);
+                              num_options, argc_in_out, argv_in_out,
+                              fallback_resources, var);
 }
 
 Widget
-XtOpenApplication(
-    XtAppContext * app_context_return,
-    _Xconst char* application_class,
-    XrmOptionDescRec *options,
-    Cardinal num_options,
-    int *argc_in_out,
-    String *argv_in_out,
-    String *fallback_resources,
-    WidgetClass widget_class,
-    ArgList args_in,
-    Cardinal num_args_in)
+XtOpenApplication(XtAppContext *app_context_return,
+                  _Xconst char *application_class,
+                  XrmOptionDescRec *options,
+                  Cardinal num_options,
+                  int *argc_in_out,
+                  String *argv_in_out,
+                  String *fallback_resources,
+                  WidgetClass widget_class,
+                  ArgList args_in, Cardinal num_args_in)
 {
     extern Widget _XtOpenApplication();
+
     VENDORINIT
-    return _XtOpenApplication (app_context_return, application_class, options,
-			       num_options, argc_in_out, argv_in_out,
-			       fallback_resources, widget_class,
-			       args_in, num_args_in);
+        return _XtOpenApplication(app_context_return, application_class,
+                                  options, num_options, argc_in_out,
+                                  argv_in_out, fallback_resources, widget_class,
+                                  args_in, num_args_in);
 }
 
 Widget
-XtVaOpenApplication(
-    XtAppContext *app_context_return,
-    _Xconst char* application_class,
-    XrmOptionDescList options,
-    Cardinal num_options,
-    int *argc_in_out,
-    String *argv_in_out,
-    String *fallback_resources,
-    WidgetClass widget_class,
-    ...)
+XtVaOpenApplication(XtAppContext *app_context_return,
+                    _Xconst char *application_class,
+                    XrmOptionDescList options,
+                    Cardinal num_options,
+                    int *argc_in_out,
+                    String *argv_in_out,
+                    String *fallback_resources, WidgetClass widget_class, ...)
 {
-    va_list	var;
+    va_list var;
     extern Widget _XtVaOpenApplication();
 
-    VENDORINIT
-    va_start(var, widget_class);
+    VENDORINIT va_start(var, widget_class);
+
     return _XtVaOpenApplication(app_context_return, application_class, options,
-				num_options, argc_in_out, argv_in_out,
-				fallback_resources, widget_class, var);
+                                num_options, argc_in_out, argv_in_out,
+                                fallback_resources, widget_class, var);
 }
 
 #else
 
 #ifndef lint
-static int dummy;			/* avoid warning from ranlib */
+static int dummy;               /* avoid warning from ranlib */
 #endif
 
-#endif /* SUNSHLIB or AIXSHLIB */
+#endif                          /* SUNSHLIB or AIXSHLIB */
 
 #if defined(SUNSHLIB) && !defined(SHAREDCODE)
 
@@ -201,10 +194,10 @@ WidgetClass widgetClass = &widgetClassRec;
 WidgetClass coreWidgetClass = &widgetClassRec;
 
 extern ObjectClassRec objectClassRec;
-WidgetClass objectClass = (WidgetClass)&objectClassRec;
+WidgetClass objectClass = (WidgetClass) &objectClassRec;
 
 extern RectObjClassRec rectObjClassRec;
-WidgetClass rectObjClass = (WidgetClass)&rectObjClassRec;
+WidgetClass rectObjClass = (WidgetClass) &rectObjClassRec;
 
 extern ShellClassRec shellClassRec;
 WidgetClass shellWidgetClass = (WidgetClass) &shellClassRec;
@@ -222,7 +215,8 @@ extern TopLevelShellClassRec topLevelShellClassRec;
 WidgetClass topLevelShellWidgetClass = (WidgetClass) &topLevelShellClassRec;
 
 extern ApplicationShellClassRec applicationShellClassRec;
-WidgetClass applicationShellWidgetClass = (WidgetClass) &applicationShellClassRec;
+WidgetClass applicationShellWidgetClass =
+    (WidgetClass) &applicationShellClassRec;
 
 extern SessionShellClassRec sessionShellClassRec;
 WidgetClass sessionShellWidgetClass = (WidgetClass) &sessionShellClassRec;
@@ -230,4 +224,4 @@ WidgetClass sessionShellWidgetClass = (WidgetClass) &sessionShellClassRec;
 extern HookObjClassRec hookObjClassRec;
 WidgetClass hookObjectClass = (WidgetClass) &hookObjClassRec;
 
-#endif /* SUNSHLIB */
+#endif                          /* SUNSHLIB */
